@@ -1,11 +1,9 @@
 #ifndef __GHCVERSION_H__
 #define __GHCVERSION_H__
 
-#ifndef __GLASGOW_HASKELL__
-# define __GLASGOW_HASKELL__ 710
-#endif
+#define __GLASGOW_HASKELL__ 804
 
-#define __GLASGOW_HASKELL_PATCHLEVEL1__ 2
+#define __GLASGOW_HASKELL_PATCHLEVEL1__ 4
 
 #define MIN_VERSION_GLASGOW_HASKELL(ma,mi,pl1,pl2) (\
    ((ma)*100+(mi)) <  __GLASGOW_HASKELL__ || \
